#!/usr/bin/perl
#
# This code is distributed under the terms of the GPL
#
# (c) Scott Knight 2004
# scott@scottknight.com

package Ambit;

use strict;

my $VERSION = 0.2;

my $debug = 0;
my $params;
my $data;

use SRK::BMM::Modem::CableModem;
our @ISA = qw(CableModem);

my %defaults = (
	'modem_name'	=>	'Ambit Cable Modem',
	'host'		=>	'192.168.100.1',
	'port'		=>	'80',
	'ui_user'	=>	'root',
	'ui_pass'	=>	'root',
	);

sub new {
	my ($class) = @_;

	$params = $_[1];
	$data = $_[2];

	if (defined $params->{'debug'}) { $debug = $params->{'debug'} };
	printDebug(1, "VERSION $VERSION");
	printDebug(2, 'new() starting');

	my $self = $class->SUPER::new($params, $data, \%defaults);
	bless $self, $class;

	printDebug(2, 'new() finished');
	return $self;
}

sub getData {
	printDebug(2, "getData() starting");
	my $self = shift;

	use SRK::HTTP;
	my $httplib = new SRK::HTTP($params);

	my $fwv = "";
	foreach my $line($httplib->getHTTPData("nonauth_P_info_out.htm")) {
		if ($line =~ s/Software Version: //g) {
			printDebug(2, "matched 'Software Version: '");
			printDebug(3, "$line");
			$line =~ s/<[^>]+>//g;
			$line =~ s/\s//g;
			chomp $line;
			$data->{'fwv'} = $line;
			printDebug(1, "fwv: '$data->{'fwv'}'");
			last;
		}
	}

	# for the Ambit 200
	if ($fwv eq "") {
		my $fw_pos = 0;
		my $fw_cnt = 0;
		foreach my $line($httplib->getHTTPData("P_configuration.html")) {
			if ($line =~ /Software/) {
				printDebug(2, "matched 'Software'");
				printDebug(3, "$line");
				$fw_cnt = 1;
			}
			if ($fw_cnt) { $fw_pos++; }
			if ($fw_pos == 2) {
				$line =~ s/<[^>]+>//g;
				$line =~ s/\s//g;
				chomp $line;
				$data->{'fwv'} = $line;
				printDebug(1, "fwv: '$data->{'fwv'}'");
				last;
			}
		}
	}

	my $fwv = "";
	foreach my $line($httplib->getHTTPData("rf_info.asp")) {
		if ($line =~ s/Software Version://g) {
			printDebug(2, "matched 'Software Version:'");
			printDebug(3, "$line");
			#$line =~ s/<[^>]+>//g;
			$line =~ s/\s//g;
			$fwv = $line;
			chomp $fwv;
			$data->{'fwv'} = $fwv;
			printDebug(1, "fwv: '$data->{'fwv'}'");
			last;
		}
	}

	foreach my $line($httplib->getHTTPData("P_upstatus.html")) {
		if ($line =~ s/(Upstream Transmit Power Level)//g) {
			printDebug(2, "matched 'Upstream Transmit Power Level'");
			printDebug(3, "$line");
			$line =~ s/(dBmV)//g;
			$line =~ s/://g;
			$line =~ s/<[^>]+>//g;
			$line =~ s/\s//g;
			chomp $line;
			if ($self->validateNumber($line)) {
				$data->{'upl'} = $line;
			}
			printDebug(1, "upl: '$data->{'upl'}'");
		}
		if ($line =~ s/(Upstream Frequency)//g) {
			printDebug(2, "matched 'Upstream Frequency'");
			printDebug(3, "$line");
			$line =~ s/(Hz)//g;
			$line =~ s/://g;
			$line =~ s/<[^>]+>//g;
			$line =~ s/\s//g;
			chomp $line;
			if ($self->validateNumber($line)) {
				$data->{'ufr'} = $line/1000000;
			}
			printDebug(1, "ufr: '$data->{'ufr'}'");
		}
	}

	foreach my $line($httplib->getHTTPData("P_downstatus.html")) {
		if ($line =~ s/(Downstream Receive Power Level)//g) {
			printDebug(2, "matched 'Downstream Receive Power Level'");
			printDebug(3, "$line");
			$line =~ s/(dBmV)//g;
			$line =~ s/://g;
			$line =~ s/<[^>]+>//g;
			$line =~ s/\s//g;
			chomp $line;
			if ($self->validateNumber($line)) {
				$data->{'dpl'} = $line;
			}
			printDebug(1, "dpl: '$data->{'dpl'}'");
		}
		if ($line =~ s/(Downstream SNR)//g) {
			printDebug(2, "matched 'Downstream SNR'");
			printDebug(3, "$line");
			$line =~ s/(dB)//g;
			$line =~ s/://g;
			$line =~ s/<[^>]+>//g;
			$line =~ s/\s//g;
			chomp $line;
			if ($self->validateNumber($line)) {
				$data->{'dsn'} = $line;
			}
			printDebug(1, "dsn: '$data->{'dsn'}'");
		}
		if ($line =~ s/(Downstream Frequency)//g) {
			printDebug(2, "matched 'Downstream Frequency'");
			printDebug(3, "$line");
			$line =~ s/(Hz)//g;
			$line =~ s/://g;
			$line =~ s/<[^>]+>//g;
			$line =~ s/\s//g;
			chomp $line;
			if ($self->validateNumber($line)) {
				$data->{'dfr'} = $line/1000000;
			}
			printDebug(1, "dfr: '$data->{'dfr'}'");
		}
	}

	printDebug(2, "getData() finished");
	return 1;
}

sub printDebug {
	if ($debug >= $_[0]) {
		printf "***Ambit.pm*** $_[1]\n";
	}
}

1;
