#!/usr/bin/perl
#
# This code is distributed under the terms of the GPL
#
# (c) Scott Knight 2004
# scott@scottknight.com

# This code is tested on BRG-3520

package Hitron_BRG3520;

use strict;

my $VERSION = 0.2;

my $debug = 0;
my $params;
my $data;

use SRK::BMM::Modem::CableModem;
our @ISA = qw(CableModem);

my %defaults = (
	'modem_name'	=>	'Hitron BRG-3520',
	'host'		=>	'192.168.100.1',
	'port'		=>	'80',
	'ui_user'	=>	'admin',
	'ui_pass'	=>	'Hitron',
	);

sub new {
	my ($class) = @_;

	$params = $_[1];
	$data = $_[2];

	if (defined $params->{'debug'}) { $debug = $params->{'debug'} };
	printDebug(1, "VERSION $VERSION");
	printDebug(2, 'new() starting');

	my $self = $class->SUPER::new($params, $data, \%defaults);
	bless $self, $class;

	printDebug(2, 'new() finished');
	return $self;
}

sub getData {
	printDebug(2, "getData() starting");
	my $self = shift;

	use SRK::HTTP;
	my $httplib = new SRK::HTTP($params);

	my $fwv = "";
	my $count = 0;
	my $pos = 0;
	foreach my $line($httplib->getHTTPData("rf_info.asp")) {
		if ($line =~ s/Software Version://g) {
			printDebug(2, "matched 'Software Version:'");
			$count = 1;
		}
		if ($count) { $pos++; }
		if ($pos == 4) {
			printDebug(3, "$line");
			#$line =~ s/<[^>]+>//g;
			$line =~ s/\s//g;
			$fwv = $line;
			chomp $fwv;
			$data->{'fwv'} = $fwv;
			printDebug(1, "fwv: '$data->{'fwv'}'");
			last;
		}
	}

	my $db_pos = 0; my $hz_pos = 0;
	foreach my $line($httplib->getHTTPData("rf_signal.asp")) {
		if ($line =~ s/(Channel Power:)//g) {
			printDebug(2, "matched 'Channel Power:'");
			printDebug(3, "$line");
			$line =~ s/(dBmV)//g;
			$line =~ s/<[^>]+>//g;
			$line =~ s/\s//g;
			if ($db_pos == 0) {
				if ($self->validateNumber($line)) {
					$data->{'dpl'} = $line;
				}
				printDebug(1, "dpl: '$data->{'dpl'}'");
			}
			if ($db_pos == 1) {
				if ($self->validateNumber($line)) {
					$data->{'upl'} = $line;
				}
				printDebug(1, "upl: '$data->{'upl'}'");
			}
			$db_pos++;
		}
		if ($line =~ s/(SNR:)//g) {
			printDebug(2, "matched 'SNR:'");
			printDebug(3, "$line");
			$line =~ s/(dB)//g;
			$line =~ s/<[^>]+>//g;
			$line =~ s/\s//g;
			if ($self->validateNumber($line)) {
				$data->{'dsn'} = $line;
			}
			printDebug(1, "dsn: '$data->{'dsn'}'");
		}
		if ($line =~ s/(Hz)//g) {
			if ($line =~ s/(Frequency:)//g) {
				printDebug(2, "matched 'Frequency:'");
				printDebug(3, "$line");
				$line =~ s/<[^>]+>//g;
				$line =~ s/\s//g;
				if ($hz_pos == 0) {
					if ($self->validateNumber($line)) {
						$data->{'dfr'} = $line/1000000;
					}
					printDebug(1, "dfr: '$data->{'dfr'}'");
				}
				if ($hz_pos == 1) {
					if ($self->validateNumber($line)) {
						$data->{'ufr'} = $line/1000000;
					}
					printDebug(1, "ufr: '$data->{'ufr'}'");
				}
				$hz_pos++;
			}
		}
	}

	printDebug(2, "getData() finished");
	return 1;
}

sub printDebug {
	if ($debug >= $_[0]) {
		printf "***Hitron_BRG3520.pm*** $_[1]\n";
	}
}

1;
