#!/usr/bin/perl
#
# This code is distributed under the terms of the GPL
#
# (c) Scott Knight 2004
# scott@scottknight.com

# This code is tested on BEFCMU10 v2

package Linksys_BEFCMU10v2;

use strict;

my $VERSION = 0.2;

my $debug = 0;
my $params;
my $data;

use SRK::BMM::Modem::CableModem;
our @ISA = qw(CableModem);

my %defaults = (
	'modem_name'	=>	'Linksys BEFCMU10v2',
	'host'		=>	'192.168.100.1',
	'port'		=>	'80',
	'ui_user'	=>	'',
	'ui_pass'	=>	'',
	);

sub new {
	my ($class) = @_;

	$params = $_[1];
	$data = $_[2];

	if (defined $params->{'debug'}) { $debug = $params->{'debug'} };
	printDebug(1, "VERSION $VERSION");
	printDebug(2, 'new() starting');

	my $self = $class->SUPER::new($params, $data, \%defaults);
	bless $self, $class;

	printDebug(2, 'new() finished');
	return $self;
}

sub getData {
	printDebug(2, "getData() starting");
	my $self = shift;

	use SRK::HTTP;
	my $httplib = new SRK::HTTP($params);

	my $counter = 0;
	foreach my $line($httplib->getHTTPData("cminfo.htm")) {
		# actually need the line after the one that contains Software Version
		if ($counter == 1) {
			printDebug(2, "grabbed the next line");
			printDebug(3, "$line");
			my $fwv = $line;
			$fwv =~ s/<[^>]+>//g;
			$fwv =~ s/\([^\)]+\)//g;
			$fwv =~ s/\&nbsp\;//g;
			$fwv =~ s/\s//g;
			$data->{'fwv'} = $fwv;
			printDebug(1, "fwv: '$data->{'fwv'}'");
			$counter++; 
		}
		if ($line =~ m/Software Version/g) {
			printDebug(2, "matched 'Software Version'");
			printDebug(3, "$line");
			$counter++; 
		}
	}

	my $db_pos = 0; my $hz_pos = 0;
	foreach my $line($httplib->getHTTPData("signal.htm")) {
		if ($line =~ /(dB)/) {
			printDebug(2, "matched 'dB'");
			printDebug(3, "$line");
			if ($line =~ m/([+-]?\d+\.?\d*|\.\d+)/g) {
				$line =~ s/\&nbsp\;//g;
				$line =~ s/<[^>]+>//g;
				$line = substr($line, 0, index($line, " dB"));
				$line =~ s/\s//g;
				if ($db_pos == 0) {
					if ($self->validateNumber($line)) {
						$data->{'dpl'} = $line;
					}
					printDebug(1, "dpl: '$data->{'dpl'}'");
				}
				if ($db_pos == 1) {
					if ($self->validateNumber($line)) {
						$data->{'dsn'} = $line;
					}
					printDebug(1, "dsn: '$data->{'dsn'}'");
				}
				if ($db_pos == 2) {
					if ($self->validateNumber($line)) {
						$data->{'upl'} = $line;
					}
					printDebug(1, "upl: '$data->{'upl'}'");
				}
				$db_pos++;
			}
		}
		if ($line =~ /(Hz)/) {
			printDebug(2, "matched 'Hz'");
			printDebug(3, "$line");
			if ($line =~ m/([+-]?\d+\.?\d*|\.\d+)/g) {
				$line =~ s/\&nbsp\;//g;
				$line =~ s/<[^>]+>//g;
				$line = substr($line, 0, index($line, " Hz"));
				$line =~ s/\s//g;
				if ($hz_pos == 0) {
					if ($self->validateNumber($line)) {
						$data->{'dfr'} = $line/1000000;
					}
					printDebug(1, "dfr: '$data->{'dfr'}'");
				}
				if ($hz_pos == 1) {
					if ($self->validateNumber($line)) {
						$data->{'ufr'} = $line/1000000;
					}
					printDebug(1, "ufr: '$data->{'ufr'}'");
				}
				$hz_pos++;
			}
		}
	}

	printDebug(2, "getData() finished");
	return 1;
}

sub printDebug {
	if ($debug >= $_[0]) {
		printf "***Linksys_BEFCMU10v2.pm*** $_[1]\n";
	}
}

1;
