#!/usr/bin/perl
#
# This code is distributed under the terms of the GPL
#
# (c) Scott Knight 2004
# scott@scottknight.com

# This code is tested on SB5100, SB4100, SB4200

package Motorola_SURFboard;

use strict;

my $VERSION = 0.3;

my $debug = 0;
my $params;
my $data;

use SRK::BMM::Modem::CableModem;
our @ISA = qw(CableModem);

my %defaults = (
	'modem_name'	=>	'Motorola SURFboard',
	'host'		=>	'192.168.100.1',
	'port'		=>	'80',
	'ui_user'	=>	'',
	'ui_pass'	=>	'',
	);

sub new {
	my ($class) = @_;

	$params = $_[1];
	$data = $_[2];

	if (defined $params->{'debug'}) { $debug = $params->{'debug'} };
	printDebug(1, "VERSION $VERSION");
	printDebug(2, 'new() starting');

	my $self = $class->SUPER::new($params, $data, \%defaults);
	bless $self, $class;

	printDebug(2, 'new() finished');
	return $self;
}

sub getData {
	printDebug(2, "getData() starting");
	my $self = shift;

	use SRK::HTTP;
	my $httplib = new SRK::HTTP($params);

	foreach my $line($httplib->getHTTPData("mainhelpdata.html")) {
		if ($line =~ s/Software Version: //g) {
			$line =~ s/<[^>]+>//g;
			chomp $line;
			$data->{'fwv'} = $line;
		}
	}

	#if ($fwv ne "") {
	#$defaults{'modem_name'} = $defaults{'modem_name'}." SB5100";
	#}

	my $db_pos = 0; my $hz_pos = 0;
	foreach my $line($httplib->getHTTPData("signaldata.html")) {
		if ($line =~ /(dB)/) {
			if ($line =~ m/([+-]?\d+\.?\d*|\.\d+)/g) {
				if ($db_pos == 0) {
					if ($self->validateNumber($1)) {
						$data->{'dsn'} = $1;
					}
					printDebug(1, "dsn: '$data->{'dsn'}'");
				}
				if ($db_pos == 1) {
					if ($self->validateNumber($1)) {
						$data->{'dpl'} = $1;
					}
					printDebug(1, "dpl: '$data->{'dpl'}'");
				}
				if ($db_pos == 2) {
					if ($self->validateNumber($1)) {
						$data->{'upl'} = $1;
					}
					printDebug(1, "upl: '$data->{'upl'}'");
				}
				$db_pos++;
			}
		}
		if ($line =~ /(Hz)/) {
			if ($line =~ m/([+-]?\d+\.?\d*|\.\d+)/g) {
				if ($hz_pos == 0) {
					if ($self->validateNumber($1)) {
						$data->{'dfr'} = $1/1000000;
					}
					printDebug(1, "dfr: '$data->{'dfr'}'");
				}
				if ($hz_pos == 1) {
					if ($self->validateNumber($1)) {
						$data->{'ufr'} = $1/1000000;
					}
					printDebug(1, "ufr: '$data->{'ufr'}'");
				}
				$hz_pos++;
			}
		}
	}

	printDebug(2, "getData() finished");
	return 1;
}

sub printDebug {
	if ($debug >= $_[0]) {
		printf "***Motorola_SURFboard.pm*** $_[1]\n";
	}
}

1;
