#!/usr/bin/perl
#
# This code is distributed under the terms of the GPL
#
# (c) Scott Knight 2004
# scott@scottknight.com

# This code is tested on CM115

package Nortel_CM115;

use strict;

my $VERSION = 0.1;

my $debug = 0;
my $params;
my $data;

use SRK::BMM::Modem::CableModem;
our @ISA = qw(CableModem);

my %defaults = (
	'modem_name'	=>	'Nortel Networks CM115',
	'host'		=>	'192.168.100.1',
	'port'		=>	'80',
	'ui_user'	=>	'',
	'ui_pass'	=>	'',
	);

sub new {
	my ($class) = @_;

	$params = $_[1];
	$data = $_[2];

	if (defined $params->{'debug'}) { $debug = $params->{'debug'} };
	printDebug(1, "VERSION $VERSION");
	printDebug(2, 'new() starting');

	my $self = $class->SUPER::new($params, $data, \%defaults);
	bless $self, $class;

	printDebug(2, 'new() finished');
	return $self;
}

sub getData {
	printDebug(2, "getData() starting");
	my $self = shift;

	use SRK::HTTP;
	my $httplib = new SRK::HTTP($params);

	my $fwv = "";
	my $count = 0;
	my $pos = 0;
	foreach my $line($httplib->getHTTPData("index.html")) {
		if ($line =~ /Software Version/) {
			printDebug(2, "matched 'Software Version'");
			$count = 1;
		}
		if ($count) { $pos++; }
		if ($pos == 2) {
			printDebug(3, "$line");
			$line =~ s/\&nbsp\;//g;
			$line =~ s/<[^>]+>//g;
			$line =~ s/\s//g;
			chomp $line;
			$data->{'fwv'} = $line;
			printDebug(1, "fwv: '$data->{'fwv'}'");
			last;
		}
	}

	my $db_pos = 0; my $hz_pos = 0;
	foreach my $line($httplib->getHTTPData("status.html")) {
		if ($line =~ /(dB)/) {
			printDebug(2, "matched 'dB'");
			printDebug(3, "$line");
			$line =~ s/\&nbsp\;//g;
			$line =~ s/<[^>]+>//g;
			$line =~ s/\s//g;
			chomp $line;
			if ($db_pos == 0) {
				$line =~ s/(dBmV)//g;
				if ($self->validateNumber($line)) {
					$data->{'dpl'} = $line;
				}
				printDebug(1, "dpl: '$data->{'dpl'}'");
			}
			if ($db_pos == 1) {
				$line =~ s/(dB)//g;
				if ($self->validateNumber($line)) {
					$data->{'dsn'} = $line;
				}
				printDebug(1, "dsn: '$data->{'dsn'}'");
			}
			if ($db_pos == 2) {
				$line =~ s/(dBmV)//g;
				if ($self->validateNumber($line)) {
					$data->{'upl'} = $line;
				}
				printDebug(1, "upl: '$data->{'upl'}'");
			}
			$db_pos++;
		}
		if ($line =~ s/(Hz)//g) {
			printDebug(2, "matched 'Hz'");
			printDebug(3, "$line");
			$line =~ s/\&nbsp\;//g;
			$line =~ s/<[^>]+>//g;
			$line =~ s/\s//g;
			chomp $line;
			if ($hz_pos == 0) {
				if ($self->validateNumber($line)) {
					$data->{'dfr'} = $line/1000000;
				}
				printDebug(1, "dfr: '$data->{'dfr'}'");
			}
			if ($hz_pos == 1) {
				if ($self->validateNumber($line)) {
					$data->{'ufr'} = $line/1000000;
				}
				printDebug(1, "ufr: '$data->{'ufr'}'");
			}
			$hz_pos++;
		}
	}

	printDebug(2, "getData() finished");
	return 1;
}

sub printDebug {
	if ($debug >= $_[0]) {
		printf "***Nortel_CM115.pm*** $_[1]\n";
	}
}

1;
