#!/usr/bin/perl
#
# This code is distributed under the terms of the GPL
#
# (c) Scott Knight 2004
# scott@scottknight.com

# This code is tested on DCM245

package RCA_DCM245;

use strict;

my $VERSION = 0.1;

my $debug = 0;
my $params;
my $data;

use SRK::BMM::Modem::CableModem;
our @ISA = qw(CableModem);

my %defaults = (
	'modem_name'	=>	'Thomson/RCA DCM245',
	'host'		=>	'192.168.100.1',
	'port'		=>	'80',
	'ui_user'	=>	'',
	'ui_pass'	=>	'',
	);

sub new {
	my ($class) = @_;

	$params = $_[1];
	$data = $_[2];

	if (defined $params->{'debug'}) { $debug = $params->{'debug'} };
	printDebug(1, "VERSION $VERSION");
	printDebug(2, 'new() starting');

	my $self = $class->SUPER::new($params, $data, \%defaults);
	bless $self, $class;

	printDebug(2, 'new() finished');
	return $self;
}

sub getData {
	printDebug(2, "getData() starting");
	my $self = shift;

	use SRK::HTTP;
	my $httplib = new SRK::HTTP($params);

	foreach my $line($httplib->getHTTPData("moreInfo.html")) {
		if ($line =~ /(Software Version)/) {
			printDebug(2, "matched 'Software Version'");
			printDebug(3, "$line");
	
			# extract the firmware version
			my $fwv = $line;
			my $fwv_tags = "Software Version:";
			my $fwv_tage = "Software Model:";
			$fwv =~ s/\&nbsp\;//g;
			$fwv =~ s/<[^>]+>//g;
			$fwv = substr($fwv, index($fwv, $fwv_tags)+length($fwv_tags));
			$fwv = substr($fwv, 0, index($fwv, $fwv_tage));
			$fwv =~ s/\s//g;
			$data->{'fwv'} = $fwv;
			printDebug(1, "fwv: '$data->{'fwv'}'");
		}
		if ($line =~ /(Forward Path)/) {
			printDebug(2, "matched 'Forward Path'");
			printDebug(3, "$line");

			# extract the downstream frequency
			my $dfr = $line;
			my $dfr_tags = "Signal Acquired at";
			my $dfr_tage = "MHz";
			$dfr = substr($dfr, index($dfr, $dfr_tags)+length($dfr_tags));
			$dfr = substr($dfr, 0, index($dfr, $dfr_tage));
			$dfr =~ s/\s//g;
			if ($self->validateNumber($dfr)) {
				$data->{'dfr'} = $dfr;
			}
			printDebug(1, "dfr: '$data->{'dfr'}'");

			# extract the downstream signal/noise ratio
			my $dsn = $line;
			my $dsn_tags = "SNR:";
			my $dsn_tage = "dB";
			$dsn = substr($dsn, index($dsn, $dsn_tags)+length($dsn_tags));
			$dsn = substr($dsn, 0, index($dsn, $dsn_tage));
			$dsn =~ s/\s//g;
			if ($self->validateNumber($dsn)) {
				$data->{'dsn'} = $dsn;
			}
			printDebug(1, "dsn: '$data->{'dsn'}'");

			# extract the downstream power level
			my $dpl = $line;
			my $dpl_tags = "Received Signal Strength:";
			my $dpl_tage = "dBmV";
			$dpl = substr($dpl, index($dpl, $dpl_tags)+length($dpl_tags));
			$dpl = substr($dpl, 0, index($dpl, $dpl_tage));
			$dpl =~ s/\s//g;
			if ($self->validateNumber($dpl)) {
				$data->{'dpl'} = $dpl;
			}
			printDebug(1, "dpl: '$data->{'dpl'}'");
		}
		if ($line =~ /(Return Path)/) {
			printDebug(2, "matched 'Return Path'");
			printDebug(3, "$line");

			# extract the upstream frequency
			my $ufr = $line;
			my $ufr_tags = "Frequency:";
			my $ufr_tage = "MHz";
			$ufr = substr($ufr, index($ufr, $ufr_tags)+length($ufr_tags));
			$ufr = substr($ufr, 0, index($ufr, $ufr_tage));
			$ufr =~ s/\s//g;
			if ($self->validateNumber($ufr)) {
				$data->{'ufr'} = $ufr;
			}
			printDebug(1, "ufr: '$data->{'ufr'}'");

			# extract the upstream power level
			my $upl = $line;
			my $upl_tags = "Power Level:";
			my $upl_tage = "dBmV";
			$upl = substr($upl, index($upl, $upl_tags)+length($upl_tags));
			$upl = substr($upl, 0, index($upl, $upl_tage));
			$upl =~ s/\s//g;
			if ($self->validateNumber($upl)) {
				$data->{'upl'} = $upl;
			}
			printDebug(1, "upl: '$data->{'upl'}'");
		}
	}

	printDebug(2, "getData() finished");
	return 1;
}

sub printDebug {
	if ($debug >= $_[0]) {
		printf "***RCA_DCM245.pm*** $_[1]\n";
	}
}

1;
