#!/usr/bin/perl
#
# This code is distributed under the terms of the GPL
#
# (c) Scott Knight 2004
# scott@scottknight.com

# This code is tested on DCM305

package RCA_DCM305;

use strict;

my $VERSION = 0.1;

my $debug = 0;
my $params;
my $data;

use SRK::BMM::Modem::CableModem;
our @ISA = qw(CableModem);

my %defaults = (
	'modem_name'	=>	'Thomson/RCA DCM305',
	'host'		=>	'192.168.100.1',
	'port'		=>	'80',
	'ui_user'	=>	'',
	'ui_pass'	=>	'',
	);

sub new {
	my ($class) = @_;

	$params = $_[1];
	$data = $_[2];

	if (defined $params->{'debug'}) { $debug = $params->{'debug'} };
	printDebug(1, "VERSION $VERSION");
	printDebug(2, 'new() starting');

	my $self = $class->SUPER::new($params, $data, \%defaults);
	bless $self, $class;

	printDebug(2, 'new() finished');
	return $self;
}

sub getData {
	printDebug(2, "getData() starting");
	my $self = shift;

	use SRK::HTTP;
	my $httplib = new SRK::HTTP($params);

	foreach my $line($httplib->getHTTPData("diagnostics_body.html")) {
		if ($line =~ s/(Software Version:)//g) {
			#printf "Matching 'Software Version:'\n";
			#printf $line;
			#printf "\n\n\n";
	
			$line =~ s/\&nbsp\;//g;
			$line =~ s/<[^>]+>//g;
			$line =~ s/\s//g;
			#printf "fwv...".$line."...\n";
			$data->{'fwv'} = $line;
				printDebug(1, "fwv: '$data->{'fwv'}'");
		}
		if ($line =~ s/(dBmV)//g) {
			#printf "Matching 'dBmV'\n";
			if ($line =~ s/(Received Signal Strength:)//g) {
				#printf $line;
				#printf "\n\n\n";

				my $dpl = $line;
				$dpl =~ s/\&nbsp\;//g;
				$dpl =~ s/<[^>]+>//g;
				$dpl =~ s/\s//g;
				#printf "dpl...".$dpl."...\n";
				if ($self->validateNumber($dpl)) {
					$data->{'dpl'} = $dpl;
				}
				printDebug(1, "dpl: '$data->{'dpl'}'");
			}
			if ($line =~ s/(Power Level:)//g) {
				#printf $line;
				#printf "\n\n\n";

				my $upl = $line;
				$upl =~ s/\&nbsp\;//g;
				$upl =~ s/<[^>]+>//g;
				$upl =~ s/\s//g;
				#printf "upl...".$upl."...\n";
				if ($self->validateNumber($upl)) {
					$data->{'upl'} = $upl;
				}
				printDebug(1, "upl: '$data->{'upl'}'");
			}
		}
		if ($line =~ s/(MHz)//g) {
			#printf "Matching 'MHz'\n";
			if ($line =~ s/(Signal Acquired at )//g) {
				#printf $line;
				#printf "\n\n\n";

				my $dfr = $line;
				$dfr =~ s/\&nbsp\;//g;
				$dfr =~ s/<[^>]+>//g;
				$dfr =~ s/\s//g;
				#printf "dfr...".$dfr."...\n";
				if ($self->validateNumber($dfr)) {
					$data->{'dfr'} = $dfr;
				}
				printDebug(1, "dfr: '$data->{'dfr'}'");
			}
			if ($line =~ s/(Frequency:)//g) {
				#printf $line;
				#printf "\n\n\n";

				my $ufr = $line;
				$ufr =~ s/\&nbsp\;//g;
				$ufr =~ s/<[^>]+>//g;
				$ufr =~ s/\s//g;
				#printf "ufr...".$ufr."...\n";
				if ($self->validateNumber($ufr)) {
					$data->{'ufr'} = $ufr;
				}
				printDebug(1, "ufr: '$data->{'ufr'}'");
			}
		}
                if ($line =~ s/(SNR:)//g) {
			my $dsn = $line;
                        $dsn =~ s/(dB)//g;
			$dsn =~ s/\&nbsp\;//g;
                        $dsn =~ s/<[^>]+>//g;
                        $dsn =~ s/\s//g;
                        #printf "dsn:...$dsn...\n";
			if ($self->validateNumber($dsn)) {
                        	$data->{'dsn'} = $dsn;
			}
			printDebug(1, "dsn: '$data->{'dsn'}'");
                }
	}

	printDebug(2, "getData() finished");
	return 1;
}

sub printDebug {
	if ($debug >= $_[0]) {
		printf "***RCA_DCM305.pm*** $_[1]\n";
	}
}

1;
