#!/usr/bin/perl
#
# This code is distributed under the terms of the GPL
#
# (c) Scott Knight 2004
# scott@scottknight.com

# This code is tested on DPX2100

package SciAtl_DPX2100;

use strict;

my $VERSION = 0.1;

my $debug = 0;
my $params;
my $data;

use SRK::BMM::Modem::CableModem;
our @ISA = qw(CableModem);

my %defaults = (
	'modem_name'	=>	'Scientific-Atlanta WebSTAR DPX2100',
	'host'		=>	'192.168.100.1',
	'port'		=>	'80',
	'ui_user'	=>	'admin',
	'ui_pass'	=>	'w2402',
	);

sub new {
	my ($class) = @_;

	$params = $_[1];
	$data = $_[2];

	if (defined $params->{'debug'}) { $debug = $params->{'debug'} };
	printDebug(1, "VERSION $VERSION");
	printDebug(2, 'new() starting');

	my $self = $class->SUPER::new($params, $data, \%defaults);
	bless $self, $class;

	printDebug(2, 'new() finished');
	return $self;
}

sub getData {
	printDebug(2, "getData() starting");
	my $self = shift;

	use SRK::HTTP;
	my $httplib = new SRK::HTTP($params);

	my $fwv = "";
	foreach my $line($httplib->getHTTPData("DpxSystem.asp")) {
		if ($line =~ s/(Software Version)//g) {
			printDebug(2, "matched 'Software Version'");
			printDebug(3, "$line");
			$line =~ s/<[^>]+>//g;
			chomp $line;
			$data->{'fwv'} = $line;
			printDebug(1, "fwv: '$data->{'fwv'}'");
			last;
		}
	}

	my $db_pos = 0;
	foreach my $line($httplib->getHTTPData("DpxSignal.asp")) {
		if ($line =~ s/(Signal to Noise Ratio)//g) {
			printDebug(2, "matched 'Signal to Noise Ratio'");
			printDebug(3, "$line");
			$line =~ s/( dB)//g;
			$line =~ s/<[^>]+>//g;
			$line =~ s/\s//g;
			chomp $line;
			if ($self->validateNumber($line)) {
				$data->{'dsn'} = $line;
			}
			printDebug(1, "dsn: '$data->{'dsn'}'");
		}
		if ($line =~ s/(Power Level)//g) {
			printDebug(2, "matched 'Power Level'");
			printDebug(3, "$line");
			$line =~ s/( dBmV)//g;
			$line =~ s/<[^>]+>//g;
			$line =~ s/\s//g;
			chomp $line;
			if ($db_pos == 0) {
				if ($self->validateNumber($line)) {
					$data->{'dpl'} = $line;
				}
				printDebug(1, "dpl: '$data->{'dpl'}'");
			}
			if ($db_pos == 1) {
				if ($self->validateNumber($line)) {
					$data->{'upl'} = $line;
				}
				printDebug(1, "upl: '$data->{'upl'}'");
			}
			$db_pos++;
		}
		if ($line =~ s/(Downstream Frequency)//g) {
			printDebug(2, "matched 'Downstream Frequency'");
			printDebug(3, "$line");
			$line =~ s/( Hz)//g;
			$line =~ s/<[^>]+>//g;
			$line =~ s/\s//g;
			chomp $line;
			if ($self->validateNumber($line)) {
				$data->{'dfr'} = $line/1000000;
			}
			printDebug(1, "dfr: '$data->{'dfr'}'");
		}
		if ($line =~ s/(Upstream Frequency)//g) {
			printDebug(2, "matched 'Upstream Frequency'");
			printDebug(3, "$line");
			$line =~ s/( Hz)//g;
			$line =~ s/<[^>]+>//g;
			$line =~ s/\s//g;
			chomp $line;
			if ($self->validateNumber($line)) {
				$data->{'ufr'} = $line/1000000;
			}
			printDebug(1, "ufr: '$data->{'ufr'}'");
		}
	}

	printDebug(2, "getData() finished");
	return 1;
}

sub printDebug {
	if ($debug >= $_[0]) {
		printf "***SciAtl_DPX2100.pm*** $_[1]\n";
	}
}

1;
