#!/usr/bin/perl
#
# This code is distributed under the terms of the GPL
#
# (c) Scott Knight 2004
# scott@scottknight.com
#
# Thanks to Drew S. Dupont (NetWhiz) for helping with this module

# This code is tested on xxxxx

package Terayon;

use strict;

my $VERSION = 0.1;

my $debug = 0;
my $params;
my $data;

use SRK::BMM::Modem::CableModem;
our @ISA = qw(CableModem);

my %defaults = (
	'modem_name'	=>	'Terayon',
	'host'		=>	'192.168.100.1',
	'port'		=>	'80',
	'ui_user'	=>	'',
	'ui_pass'	=>	'icu4at!',
	);

sub new {
	my ($class) = @_;

	$params = $_[1];
	$data = $_[2];

	if (defined $params->{'debug'}) { $debug = $params->{'debug'} };
	printDebug(1, "VERSION $VERSION");
	printDebug(2, 'new() starting');

	my $self = $class->SUPER::new($params, $data, \%defaults);
	bless $self, $class;

	printDebug(2, 'new() finished');
	return $self;
}

sub getData {
	printDebug(2, "getData() starting");
	my $self = shift;

	use SRK::HTTP;
	my $httplib = new SRK::HTTP($params);

	# login
	$httplib->loginTypePOST("checkModemPasswd");

	foreach my $line($httplib->getHTTPData("mainPage")) {
		if ($line =~ s/(Software Model: )//g) {
			printDebug(2, "matched 'Software Model: '");
			printDebug(3, "$line");
		
			# extract the firmware version
			$line =~ s/<[^>]+>//g;
			$line =~ s/\s//g;
			$data->{'fwv'} = $line;
			printDebug(1, "fwv: '$data->{'fwv'}'");
		}
	}
	foreach my $line($httplib->getHTTPData("modemRfPage")) {
		if ($line =~ s/(Rx Frequency)//g) {
			printDebug(2, "matched 'Rx Frequency'");
			printDebug(3, "$line");

			# extract the downstream frequency
			$line =~ s/(Hz)//g;
			$line =~ s/<[^>]+>//g;
			chomp $line;
			if ($self->validateNumber($line)) {
				$data->{'dfr'} = $line/1000000;
			}
			printDebug(1, "dfr: '$data->{'dfr'}'");
		}
		if ($line =~ s/(Tx Frequency)//g) {
			printDebug(2, "matched 'Tx Frequency'");
			printDebug(3, "$line");

			# extract the upstream frequency
			$line =~ s/(Hz)//g;
			$line =~ s/<[^>]+>//g;
			chomp $line;
			if ($self->validateNumber($line)) {
				$data->{'ufr'} = $line/1000000;
			}
			printDebug(1, "ufr: '$data->{'ufr'}'");
		}
		if ($line =~ s/(Downstream SNR)//g) {
			printDebug(2, "matched 'Downstream SNR'");
			printDebug(3, "$line");

			# extract the downstream signal/noise ratio
			$line =~ s/(dB)//g;
			$line =~ s/<[^>]+>//g;
			chomp $line;
			if ($self->validateNumber($line)) {
				$data->{'dsn'} = $line;
			}
			printDebug(1, "dsn: '$data->{'dsn'}'");
		}
		if ($line =~ s/(Rx Power)//g) {
			printDebug(2, "matched 'Rx Power'");
			printDebug(3, "$line");

			# extract the downstream power level
			$line =~ s/(dBmV)//g;
			$line =~ s/<[^>]+>//g;
			chomp $line;
			if ($self->validateNumber($line)) {
				$data->{'dpl'} = $line;
			}
			printDebug(1, "dpl: '$data->{'dpl'}'");
		}
		if ($line =~ s/(Tx Power)//g) {
			printDebug(2, "matched 'Tx Power'");
			printDebug(3, "$line");

			# extract the upstream power level
			$line =~ s/(dBmV)//g;
			$line =~ s/<[^>]+>//g;
			chomp $line;
			if ($self->validateNumber($line)) {
				$data->{'upl'} = $line;
			}
			printDebug(1, "upl: '$data->{'upl'}'");
		}
	}

	# logout
	#$httplib->logoutTypePOST("logout.htm");

	printDebug(2, "getData() finished");
	return 1;
}

sub printDebug {
	if ($debug >= $_[0]) {
		printf "***Terayon.pm*** $_[1]\n";
	}
}

1;
