#!/usr/bin/perl
#
# This code is distributed under the terms of the GPL
#
# (c) Scott Knight 2004
# scott@scottknight.com

package ZyXEL_Prestige_900;

use strict;

my $VERSION = 0.1;

my $debug = 0;
my $params;
my $data;

use SRK::BMM::Modem::CableModem;
our @ISA = qw(CableModem);

my %defaults = (
	'modem_name'	=>	'ZyXEL Prestige 900',
	'host'		=>	'192.168.100.1',
	'port'		=>	'80',
	'ui_user'	=>	'user',
	'ui_pass'	=>	'1234',
	);

sub new {
	my ($class) = @_;

	$params = $_[1];
	$data = $_[2];

	if (defined $params->{'debug'}) { $debug = $params->{'debug'} };
	printDebug(1, "VERSION $VERSION");
	printDebug(2, 'new() starting');

	my $self = $class->SUPER::new($params, $data, \%defaults);
	bless $self, $class;

	printDebug(2, 'new() finished');
	return $self;
}

sub getData {
	printDebug(2, "getData() starting");
	my $self = shift;

	use SRK::HTTP;
	my $httplib = new SRK::HTTP($params);

	my ($tags, $tage);
	foreach my $line($httplib->getHTTPData("RgSwInfo.asp")) {
		if ($line =~ s/Software Version//g) {
			printDebug(2, "matched 'Software Version'");
			printDebug(3, "$line");

			# extract the firmware version
			my $fwv = $line;
			$fwv =~ s/<[^>]+>//g;
			chomp $fwv;
			$data->{'fwv'} = $fwv;
			printDebug(1, "fwv: '$data->{'fwv'}'");
		}
	}

	foreach my $line($httplib->getHTTPData("RgConnect.asp")) {
		if ($line =~ /(Downstream Frequency)/) {
			printDebug(2, "matched 'Downstream Frequency'");
			printDebug(3, "$line");

			# extract the downstream frequency
			my $dfr = $line;
			my $tags = "Downstream Frequency";
			my $tage = "Downstream Power";
			$dfr =~ s/\&nbsp\;//g;
			$dfr =~ s/<[^>]+>//g;
			$dfr = substr($dfr, index($dfr, $tags)+length($tags));
			$dfr = substr($dfr, 0, index($dfr, $tage));
			$dfr =~ s/\s//g;
			chomp $dfr;
			if ($self->validateNumber($dfr)) {
				$data->{'dfr'} = $dfr;
			}
			printDebug(1, "dfr: '$data->{'dfr'}'");

			# extract the downstream power
			my $dpl = $line;
			$tags = "Downstream Power";
			$tage = " dBmV";
			$dpl =~ s/\&nbsp\;//g;
			$dpl =~ s/<[^>]+>//g;
			$dpl = substr($dpl, index($dpl, $tags)+length($tags));
			$dpl = substr($dpl, 0, index($dpl, $tage));
			$dpl =~ s/\s//g;
			chomp $dpl;
			if ($self->validateNumber($dpl)) {
				$data->{'dpl'} = $dpl;
			}
			printDebug(1, "dpl: '$data->{'dpl'}'");

		}
		if ($line =~ /(Upstream Frequency)/) {
			printDebug(2, "matched 'Upstream Frequency'");
			printDebug(3, "$line");

			# extract the downstream frequency
			my $ufr = $line;
			$tags = "Upstream Frequency";
			$tage = "Upstream Power";
			$ufr =~ s/\&nbsp\;//g;
			$ufr =~ s/<[^>]+>//g;
			$ufr = substr($ufr, index($ufr, $tags)+length($tags));
			$ufr = substr($ufr, 0, index($ufr, $tage));
			$ufr =~ s/\s//g;
			chomp $ufr;
			if ($self->validateNumber($ufr)) {
				$data->{'ufr'} = $ufr;
			}
			printDebug(1, "ufr: '$data->{'ufr'}'");

			# extract the downstream power
			my $upl = $line;
			$tags = "Upstream Power";
			$tage = " dBmV";
			$upl =~ s/\&nbsp\;//g;
			$upl =~ s/<[^>]+>//g;
			$upl = substr($upl, index($upl, $tags)+length($tags));
			$upl = substr($upl, 0, index($upl, $tage));
			$upl =~ s/\s//g;
			chomp $upl;
			if ($self->validateNumber($upl)) {
				$data->{'upl'} = $upl;
			}
			printDebug(1, "upl: '$data->{'upl'}'");

		}
		if ($line =~ /(SNR)/) {
			printDebug(2, "Matching 'SNR'");
			printDebug(3, "$line");
	
			my $dsn = $line;
			$tags = "SNR";
			$tage = " dB";
			$dsn =~ s/\&nbsp\;//g;
			$dsn =~ s/<[^>]+>//g;
			$dsn = substr($dsn, index($dsn, $tags)+length($tags));
			$dsn = substr($dsn, 0, index($dsn, $tage));
			$dsn =~ s/\s//g;
			chomp $dsn;
			if ($self->validateNumber($dsn)) {
				$data->{'dsn'} = $dsn;
			}
			printDebug(1, "dsn: '$data->{'dsn'}'");
		}
	}

	printDebug(2, "getData() finished");
	return 1;
}

sub printDebug {
	if ($debug >= $_[0]) {
		printf "***ZyXEL_Prestige_900.pm*** $_[1]\n";
	}
}

1;
