#!/usr/bin/perl
#
# This code is distributed under the terms of the GPL
#
# (c) Scott Knight 2004
# scott@scottknight.com

# This code is tested on D-Link 300G

package DLink_300g;

use strict;

my $VERSION = 0.1;

my $debug = 0;
my $params;
my $data;

use SRK::BMM::Modem::DSLModem;
our @ISA = qw(DSLModem);

my %defaults = (
	'modem_name'	=>	'D-Link 300G',
	'host'		=>	'10.1.1.1',
	'port'		=>	'80',
	'ui_user'	=>	'',
	'ui_pass'	=>	'',
	);

sub new {
	my ($class) = @_;

	$params = $_[1];
	$data = $_[2];

	if (defined $params->{'debug'}) { $debug = $params->{'debug'} };
	printDebug(1, "VERSION $VERSION");
	printDebug(2, 'new() starting');

	my $self = $class->SUPER::new($params, $data, \%defaults);
	bless $self, $class;

	printDebug(2, 'new() finished');
	return $self;
}

sub getData {
	printDebug(2, "getData() starting");
	my $self = shift;

	use SRK::HTTP;
	my $httplib = new SRK::HTTP($params);

	my ($tags, $tage);
	foreach my $line($httplib->getHTTPData("PopOutPage?id=24")) {
		if ($line =~ /(Local\ Tx\ Power:)/) {
			printDebug(2, "Matching 'Local Tx Power:'");
			printDebug(3, "$line");
	
			my $upl = $line;
			$tags = "Local Tx Power:";
			$tage = "dB";
			$upl =~ s/\&nbsp\;//g;
			$upl =~ s/<[^>]+>//g;
			$upl = substr($upl, index($upl, $tags)+length($tags));
			$upl = substr($upl, 0, index($upl, $tage));
			$upl =~ s/\s//g;
			if ($self->validateNumber($upl)) {
				$data->{'upl'} = $upl;
			}
			printDebug(1, "upl: '$data->{'upl'}'");
		}
		if ($line =~ /(Remote\ Tx\ Power:)/) {
			printDebug(2, "Matching 'Remote Tx Power:'");
			printDebug(3, "$line");
	
			my $dpl = $line;
			$tags = "Remote Tx Power:";
			$tage = "dB";
			$dpl =~ s/\&nbsp\;//g;
			$dpl =~ s/<[^>]+>//g;
			$dpl = substr($dpl, index($dpl, $tags)+length($tags));
			$dpl = substr($dpl, 0, index($dpl, $tage));
			$dpl =~ s/\s//g;
			if ($self->validateNumber($dpl)) {
				$data->{'dpl'} = $dpl;
			}
			printDebug(1, "dpl: '$data->{'dpl'}'");
		}
		if ($line =~ /(Local\ Line\ Atten.:)/) {
			printDebug(2, "Matching 'Local Line Atten.:'");
			printDebug(3, "$line");
	
			my $ula = $line;
			$tags = "Local Line Atten.:";
			$tage = "dB";
			$ula =~ s/\&nbsp\;//g;
			$ula =~ s/<[^>]+>//g;
			$ula = substr($ula, index($ula, $tags)+length($tags));
			$ula = substr($ula, 0, index($ula, $tage));
			$ula =~ s/\s//g;
			if ($self->validateNumber($ula)) {
				$data->{'ula'} = $ula;
			}
			printDebug(1, "ula: '$data->{'ula'}'");
		}
		if ($line =~ /(Remote\ Line\ Atten.:)/) {
			printDebug(2, "Matching 'Remote Line Atten.:'");
			printDebug(3, "$line");
	
			my $dla = $line;
			$tags = "Remote Line Atten.:";
			$tage = "dB";
			$dla =~ s/\&nbsp\;//g;
			$dla =~ s/<[^>]+>//g;
			$dla = substr($dla, index($dla, $tags)+length($tags));
			$dla = substr($dla, 0, index($dla, $tage));
			$dla =~ s/\s//g;
			if ($self->validateNumber($dla)) {
				$data->{'dla'} = $dla;
			}
			printDebug(1, "dla: '$data->{'dla'}'");
		}
		if ($line =~ /(Local\ SNR\ Margin:)/) {
			printDebug(2, "Matching 'Local SNR Margin:'");
			printDebug(3, "$line");
	
			my $usn = $line;
			$tags = "Local SNR Margin:";
			$tage = "dB";
			$usn =~ s/\&nbsp\;//g;
			$usn =~ s/<[^>]+>//g;
			$usn = substr($usn, index($usn, $tags)+length($tags));
			$usn = substr($usn, 0, index($usn, $tage));
			$usn =~ s/\s//g;
			if ($self->validateNumber($usn)) {
				$data->{'usn'} = $usn;
			}
			printDebug(1, "usn: '$data->{'usn'}'");
		}
		if ($line =~ /(Remote\ SNR\ Margin:)/) {
			printDebug(2, "Matching 'Remote SNR Margin:'");
			printDebug(3, "$line");
	
			my $dsn = $line;
			$tags = "Remote SNR Margin:";
			$tage = "dB";
			$dsn =~ s/\&nbsp\;//g;
			$dsn =~ s/<[^>]+>//g;
			$dsn = substr($dsn, index($dsn, $tags)+length($tags));
			$dsn = substr($dsn, 0, index($dsn, $tage));
			$dsn =~ s/\s//g;
			if ($self->validateNumber($dsn)) {
				$data->{'dsn'} = $dsn;
			}
			printDebug(1, "dsn: '$data->{'dsn'}'");
		}
		if ($line =~ /(AS1)/) {
			printDebug(2, "Matching 'AS1'");
			printDebug(3, "$line");
	
			my $dsp = $line;
			$tags = "AS0";
			$dsp = substr($dsp, index($dsp, $tags)+length($tags));
			$tags = "<td class=\"alignleft\">";
			$dsp = substr($dsp, index($dsp, $tags)+length($tags));
			$dsp = substr($dsp, index($dsp, $tags)+length($tags));
			$dsp = substr($dsp, index($dsp, $tags)+length($tags));
			$dsp = substr($dsp, index($dsp, $tags)+length($tags));
			$tage = "AS1";
			$dsp = substr($dsp, 0, index($dsp, $tage));
			$dsp =~ s/<[^>]+>//g;
			$dsp =~ s/\s//g;
			if ($self->validateNumber($dsp)) {
				$data->{'dsp'} = $dsp;
			}
			printDebug(1, "dsp: '$data->{'dsp'}'");
		}
		if ($line =~ /(LS0)/) {
			printDebug(2, "Matching 'LS0'");
			printDebug(3, "$line");
	
			my $usp = $line;
			$tags = "LS0(kbps):";
			$usp = substr($usp, index($usp, $tags)+length($tags));
			$tags = "<td class=\"alignleft\">";
			$usp = substr($usp, index($usp, $tags)+length($tags));
			$usp = substr($usp, index($usp, $tags)+length($tags));
			$tage = "-";
			$usp = substr($usp, 0, index($usp, $tage));
			$usp =~ s/<[^>]+>//g;
			$usp =~ s/\s//g;
			if ($self->validateNumber($usp)) {
				$data->{'usp'} = $usp;
			}
			printDebug(1, "usp: '$data->{'usp'}'");
		}
	}

	printDebug(2, "getData() finished");
	return 1;
}

sub printDebug {
	if ($debug >= $_[0]) {
		printf "***DLink_300g.pm*** $_[1]\n";
	}
}

1;
