#!/usr/bin/perl
#
# This code is distributed under the terms of the GPL
#
# (c) Scott Knight 2004
# scott@scottknight.com

# This code is tested on Westell WireSpeed 327W

package Westell_327W;

use strict;

my $VERSION = 0.1;

my $debug = 0;
my $params;
my $data;

use SRK::BMM::Modem::DSLModem;
our @ISA = qw(DSLModem);

my %defaults = (
	'modem_name'	=>	'Westell WireSpeed 327W',
	'host'		=>	'192.168.1.1',
	'port'		=>	'80',
	'ui_user'	=>	'',
	'ui_pass'	=>	'',
	);

sub new {
	my ($class) = @_;

	$params = $_[1];
	$data = $_[2];

	if (defined $params->{'debug'}) { $debug = $params->{'debug'} };
	printDebug(1, "VERSION $VERSION");
	printDebug(2, 'new() starting');

	my $self = $class->SUPER::new($params, $data, \%defaults);
	bless $self, $class;

	printDebug(2, 'new() finished');
	return $self;
}

sub getData {
	printDebug(2, "getData() starting");
	my $self = shift;

	use SRK::HTTP;
	my $httplib = new SRK::HTTP($params);

	my $fw_count = 0;
	my $fw_pos = 0;
	foreach my $line($httplib->getHTTPData("about.htm")) {
		if ($line =~ /(Software Version)/) {
			printDebug(2, "Matching 'Software Version'");
			$fw_count = 1;
		}
		if ($fw_count) { $fw_pos++; }
		if ($fw_pos == 2) {
			printDebug(3, "$line");
	
			$line =~ s/\&nbsp\;//g;
			$line =~ s/<[^>]+>//g;
			$line =~ s/\s//g;
			$line =~ s/VER://g;
			chomp $line;
			$data->{'fwv'} = $line;
			printDebug(1, "fwv: '$data->{'fwv'}'");
			last;
		}
	}

	my ($sp_count, $la_count, $sn_count, $pl_count) = (0, 0, 0, 0);
	my ($sp_pos, $la_pos, $sn_pos, $pl_pos) = (0, 0, 0, 0);
	foreach my $line($httplib->getHTTPData("transtat.htm")) {
		if ($line =~ /(DSL Speed)/) {
			printDebug(2, "Matching 'DSL Speed'");
			$sp_count = 1;
		}
		if ($sp_count) { $sp_pos++; }
		if ($sp_pos >= 2) {
			printDebug(3, "$line");
	
			$line =~ s/<[^>]+>//g;
			$line =~ s/\s//g;
			chomp $line;
			if ($sp_pos == 2) {
				if ($self->validateNumber($line)) {
					$data->{'dsp'} = $line;
				}
				printDebug(1, "dsp: '$data->{'dsp'}'");
			}
			if ($sp_pos == 3) {
				if ($self->validateNumber($line)) {
					$data->{'usp'} = $line;
				}
				printDebug(1, "usp: '$data->{'usp'}'");
				$sp_count = 0;
				$sp_pos = 0;
			}
		}
		if ($line =~ /(Margin)/) {
			printDebug(2, "Matching 'Margin'");
			$sn_count = 1;
		}
		if ($sn_count) { $sn_pos++; }
		if ($sn_pos >= 2) {
			printDebug(3, "$line");
	
			$line =~ s/<[^>]+>//g;
			$line =~ s/\s//g;
			chomp $line;
			if ($sn_pos == 2) {
				if ($self->validateNumber($line)) {
					$data->{'dsn'} = $line;
				}
				printDebug(1, "dsn: '$data->{'dsn'}'");
			}
			if ($sn_pos == 3) {
				if ($self->validateNumber($line)) {
					$data->{'usn'} = $line;
				}
				printDebug(1, "usn: '$data->{'usn'}'");
				$sn_count = 0;
				$sn_pos = 0;
			}
		}
		if ($line =~ /(Line Attenuation)/) {
			printDebug(2, "Matching 'Line Attenuation'");
			$la_count = 1;
		}
		if ($la_count) { $la_pos++; }
		if ($la_pos >= 2) {
			printDebug(3, "$line");
	
			$line =~ s/<[^>]+>//g;
			$line =~ s/\s//g;
			chomp $line;
			if ($la_pos == 2) {
				if ($self->validateNumber($line)) {
					$data->{'dla'} = $line;
				}
				printDebug(1, "dla: '$data->{'dla'}'");
			}
			if ($la_pos == 3) {
				if ($self->validateNumber($line)) {
					$data->{'ula'} = $line;
				}
				printDebug(1, "ula: '$data->{'ula'}'");
				$la_count = 0;
				$la_pos = 0;
			}
		}
		if ($line =~ /(Transmit Power)/) {
			printDebug(2, "Matching 'Transmit Power'");
			$pl_count = 1;
		}
		if ($pl_count) { $pl_pos++; }
		if ($pl_pos >= 2) {
			printDebug(3, "$line");
	
			$line =~ s/<[^>]+>//g;
			$line =~ s/\s//g;
			chomp $line;
			if ($pl_pos == 2) {
				if ($self->validateNumber($line)) {
					$data->{'dpl'} = $line;
				}
				printDebug(1, "dpl: '$data->{'dpl'}'");
			}
			if ($pl_pos == 3) {
				if ($self->validateNumber($line)) {
					$data->{'upl'} = $line;
				}
				printDebug(1, "upl: '$data->{'upl'}'");
				$pl_count = 0;
				$pl_pos = 0;
			}
		}
	}

	printDebug(2, "getData() finished");
	return 1;
}

sub printDebug {
	if ($debug >= $_[0]) {
		printf "***Westell_327W.pm*** $_[1]\n";
	}
}

1;
