#!/usr/bin/perl
#
# coded by Scott Knight 2004
# scott@scottknight.com
#
# This code is distributed under the terms of the GPL

package SRK::ConfigUtils;

use strict;

my $VERSION = 0.1;

my $debug = 0;
my $params;

sub new {
	my ($class) = @_;
	my $self = {
		_setParamValues		=>	undef,
		_readConfigFile		=>	undef,
		_writeConfigFile	=>	undef
	};
	bless $self, $class;

	$params = $_[1];
	if (defined $params->{'debug'}) { $debug = $params->{'debug'}; }
	if (defined $params->{'is_cgi'} && $params->{'is_cgi'} eq '0') { $debug = '0'};
	printDebug(2, "new() starting");

	my %config = (
		'filename'	=>	$params->{'config_file'}
		);

	readConfigFile($self, \%config);

	setParamValues($self, \%config, $params);

	printDebug(2, "new() finished");
	return $self;
}

sub readConfigFile {
	my $config = $_[1];
	printDebug(2, "readConfigFile() starting");

	foreach my $key (sort keys %$config) {
		printDebug(1, "config key: $key");
	}

	printDebug(1, "Reading $config->{'filename'}");
	open(CONFIG_FILE, $config->{'filename'});
	while (<CONFIG_FILE>) {
		next if /^\s*[\#\@]/;
		my ($key, $value) = $_ =~ /(\S+?)\s*=\s*(.*)/;
		if ($key && $key ne 'filename') {
			$config->{$key} = $value;
			printDebug(1, "Getting $key: \'$config->{$key}\'");
			next;
		}
	}
	close(CONFIG_FILE);

	printDebug(1, "Done reading $config->{'filename'}");
	printDebug(2, "readConfigFile() finished");
	return 1;
}

sub setParamValues {
	printDebug(2, "setParamValues() starting");
	my $config = $_[1];
	my $params = $_[2];

	#foreach my $key (sort keys %$config) {
	#printDebug(2, "config $key: $config->{$key}");
	#}
	#foreach my $key (sort keys %$params) {
	#printDebug(2, "params $key: $params->{$key}");
	#}

	foreach my $key (sort keys %$config) {
		if ($key eq 'debug' && $params->{'is_cgi'}) { next; }
		$params->{$key} = $config->{$key};
		printDebug(1, "Setting $key: \'$params->{$key}\'");
	}

	printDebug(2, "setParamValues() finished");
	return 1;
}

sub writeConfigFile {
	printDebug(2, "writeConfigFile() starting");
	my $config = $_[1];
	open(CONFIG_FILE, ">$config->{'config_file'}");
	foreach my $key (sort keys %$config) {
		printDebug(1, "$key = $config->{$key}");
		print CONFIG_FILE "$key = $config->{$key}\n";
	}
	close(CONFIG_FILE);
	printDebug(2, "writeConfigFile() finished");
	return 1;
}

sub printDebug {
	if ($debug >= $_[0]) {
		printf "***ConfigUtils.pm*** $_[1]<br>\n";
	}
}

1;
