#!/usr/bin/perl
#
# coded by Scott Knight 2004
# scott@scottknight.com
#
# This code is distributed under the terms of the GPL

package SRK::HTTP;

use strict;

my $VERSION = 0.1;

my $debug = 0;
my $params;

my $host;
my $port;
my $ui_user;
my $ui_pass;
my $ui_auth = '0';
my $pass64 = "";

my $eol = "\015\012";

use IO::Socket::INET;
use MIME::Base64 ();

sub new {
	my ($class) = @_;
	my $self = {
		_getHTTPData	=>	undef,
		_loginTypePOST	=>	undef,
		_logoutTypePOST	=>	undef
	};
	bless $self, $class;

	$params = $_[1];

	if (defined $params->{'debug'}) { $debug = $params->{'debug'} };
	printDebug(1, "VERSION $VERSION");
	printDebug(2, 'new() starting');

	$host = $params->{'host'};
	$port = $params->{'port'};
	$ui_user = $params->{'ui_user'};
	$ui_pass = $params->{'ui_pass'};

	printDebug(1, "host = '$host'");
	printDebug(1, "port = '$port'");
	printDebug(1, "ui_user = '$ui_user'");
	printDebug(1, "ui_pass = '$ui_pass'");

	if ($host eq "") {
		printDebug(1, "Changing host to 192.168.100.1 because no value was found.");
		$host = '192.168.100.1';
	}
	if ($port eq "") {
		printDebug(1, "Changing port to 80 because no value was found.");
		$port = '80';
	}

	if ($ui_user ne "" || $ui_pass ne "") {
		$ui_auth = 1;
		$pass64 = MIME::Base64::encode_base64("$ui_user:$ui_pass", "");
		printDebug(1, "pass64 = $pass64");
	}

	printDebug(2, 'new() finished');
	return $self;
}

sub getHTTPData {
	printDebug(2, "getHTTPData() starting");

	my $filename = $_[1];
	printDebug(1, "filename = '$filename'");

	printDebug(1, "Opening socket at port $port on host $host");

	my $sock;
	unless ($sock = new IO::Socket::INET (PeerAddr => $host, PeerPort => $port, Proto => 'tcp', Timeout => 5)) {
		printDebug(0, "Could not connect to http://$host:$port/$filename");
		return 0;
	}

	printDebug(1, "URL: http://$host:$port/$filename");

	my $request = "";

	$request = $request."GET /$filename HTTP/1.0".$eol;
	$request = $request."User-Agent: SRK::HTTP/$VERSION".$eol;
	$request = $request."Host: $host:$port".$eol;
	$request = $request."Accept: */*".$eol;
	$request = $request."Connection: Keep-Alive".$eol;

	if ($ui_auth) {
		$request = $request."Authorization: Basic $pass64".$eol;
	}

	$request = $request.$eol;

	printDebug(1, "");
	printDebug(1, "---request begin---");

	if ($debug >= 1) { printf $request; }
	$sock->print($request);

	printDebug(1, "---request end---");
	printDebug(1, "");

	my @httpdata = ();
	my $counter = 0;
	while (<$sock>) {
		$httpdata[$counter++] = $_;
		if ($debug > 2) { printf $httpdata[$counter-1] }
	}

	printDebug(1, "Closing socket");
	close($sock);

	printDebug(2, "getHTTPData() finished");
	return @httpdata;
}

sub loginTypePOST {
	printDebug(2, "loginTypePOST() starting");

	my $filename = $_[1];
	printDebug(1, "filename = '$filename'");

	printDebug(1, "Opening socket at port $port on host $host");

	my $sock;
	unless ($sock = new IO::Socket::INET (PeerAddr => $host, PeerPort => $port, Proto => 'tcp', Timeout => 5)) {
		printDebug(0, "Could not connect to http://$host:$port/");
		return 0;
	}

	printDebug(1, "URL: http://$host:$port/");

	my $request = "";

	$request = $request."POST /$filename HTTP/1.1".$eol;
	$request = $request."User-Agent: SRK::HTTP/$VERSION".$eol;
	$request = $request."Host: $host:$port".$eol;
	$request = $request."passwdStr=$ui_pass".$eol;
	$request = $request."Connection: Close".$eol;
	$request = $request.$eol;

	printDebug(1, "");
	printDebug(1, "---request begin---");

	if ($debug >= 1) { printf $request; }
	$sock->print($request);

	printDebug(1, "---request end---");
	printDebug(1, "");

	my @logindata = ();
	my $counter = 0;
	while (<$sock>) {
		$logindata[$counter++] = $_;
		if ($debug > 2) { printf $logindata[$counter-1] }
	}

	printDebug(1, "Closing socket");
	close($sock);

	printDebug(2, "loginTypePOST() finished");
	return @logindata;
}

sub logoutTypePOST {
	printDebug(2, "logoutTypePOST() starting");

	my $filename = $_[1];
	printDebug(1, "filename = '$filename'");

	printDebug(1, "Opening socket at port $port on host $host");

	my $sock;
	unless ($sock = new IO::Socket::INET (PeerAddr => $host, PeerPort => $port, Proto => 'tcp', Timeout => 5)) {
		printDebug(0, "Could not connect to http://$host:$port/$filename");
		return 0;
	}

	printDebug(1, "URL: http://$host:$port/$filename");

	my $request = "";

	$request = $request."GET /$filename HTTP/1.0".$eol;
	$request = $request."User-Agent: SRK::HTTP/$VERSION".$eol;
	$request = $request."Host: $host:$port".$eol;
	$request = $request."Accept: */*".$eol;
	$request = $request."Connection: Keep-Alive".$eol;

	if ($ui_auth) {
		$request = $request."Authorization: Basic $pass64".$eol;
	}

	$request = $request.$eol;

	printDebug(1, "");
	printDebug(1, "---request begin---");

	if ($debug >= 1) { printf $request; }
	$sock->print($request);

	printDebug(1, "---request end---");
	printDebug(1, "");

	my @logoutdata = ();
	my $counter = 0;
	while (<$sock>) {
		$logoutdata[$counter++] = $_;
		if ($debug > 2) { printf $logoutdata[$counter-1] }
	}

	printDebug(1, "Closing socket");
	close($sock);

	printDebug(2, "logoutTypePOST() finished");
	return @logoutdata;
}

sub printDebug {
	if ($debug >= $_[0]) {
		printf "***HTTP.pm*** $_[1]\n";
	}
}

1;
