#!/usr/bin/perl -w
#
# This code is distributed under the terms of the GPL

use strict;

my $VERSION = '1.3';

printf "Broadband Modem Monitor version $VERSION\n";

my %params = (
	'config_file'	=>	'/etc/bmm.conf',
	'debug'		=>	'0',
	'display_good'	=>	'1',
	'dpl_color'	=>	'FE6205',
	'dpl_max'	=>	'15',
	'dpl_min'	=>	'-15',
	'dsn_color'	=>	'FE6205',
	'dsn_max'	=>	'60',
	'dsn_min'	=>	'30',
	'dla_color'	=>	'FE6205',
	'dla_max'	=>	'100',
	'dla_min'	=>	'0',
	'dsp_color'	=>	'FE6205',
	'dsp_max'	=>	'1000',
	'dsp_min'	=>	'100',
	'email_from'	=>	'',
	'email_notify'	=>	'0',
	'email_server'	=>	'',
	'email_subject'	=>	'',
	'email_to'	=>	'',
	'model'		=>	'Motorola_SURFboard',
	'status_file'	=>	'/var/log/bmm',
	'title_la'	=>	'Line Attenuation',
	'title_pl'	=>	'Power Level',
	'title_sn'	=>	'Signal/Noise Ratio',
	'title_sp'	=>	'Line Speed',
	'upl_color'	=>	'5447A2',
	'upl_max'	=>	'55',
	'upl_min'	=>	'-1',
	'usn_color'	=>	'5447A2',
	'usn_max'	=>	'60',
	'usn_min'	=>	'29',
	'ula_color'	=>	'5447A2',
	'ula_max'	=>	'55',
	'ula_min'	=>	'0',
	'usp_color'	=>	'5447A2',
	'usp_max'	=>	'1000',
	'usp_min'	=>	'100'
	);

#getConfig(\%params);
use SRK::ConfigUtils;
my $bmm = new SRK::ConfigUtils(\%params);

my $debug = $params{'debug'};

# define location of rrdtool binary - CHANGE IF NEEDED
my $rrdtool = '/usr/bin/rrdtool';

# define location of images - CHANGE IF NEEDED
my $img = '/var/www/html/noc/cacti/rra';

my %data = (
	'fwv'	=>	"",
	'dsn'	=>	"NaN",
	'usn'	=>	"NaN",
	'dpl'	=>	"NaN",
	'upl'	=>	"NaN",
	'dfr'	=>	"NaN",
	'ufr'	=>	"NaN",
	'dla'	=>	"NaN",
	'ula'	=>	"NaN",
	'dsp'	=>	"NaN",
	'usp'	=>	"NaN"
	);

use SRK::BMM::Modem;
my $modem = new SRK::BMM::Modem(\%params, \%data);

if ($params{'modem_found'}) {
	$modem->getData();
}
else {
	printDebug(0, "Could not find modem $params{'model'} in the system. Exiting.");
	exit;
}

my $cable = 1;
if ($params{'modem_type'} eq 'dsl') {
	$cable = 0;
}
my $dsl = !$cable;

printf "Modem Firmware Version: $data{'fwv'}\n";
printf "Downstream S/N: $data{'dsn'} dB";
if ($dsl) { printf ", Upstream S/N: $data{'usn'} dB"; }
printf "\n";
printf "Downstream Power Level: $data{'dpl'} dBmV, Upstream Power Level: $data{'upl'} dBmV\n";

if ($dsl) {
	printf "Downstream Line Attenuation: $data{'dla'} dB, Upstream Line Attenuation: $data{'ula'} dB\n";
	printf "Downstream Speed: $data{'dsp'} kb/s, Upstream Speed: $data{'usp'} kb/s\n";
}
else {
	printf "Downstream Frequency: $data{'dfr'} MHz, Upstream Frequency: $data{'ufr'} MHz\n";
}

# define location of rrdtool database - CHANGE IF NEEDED
my $rrd = '/var/www/html/noc/cacti/bmm_cable.rrd';
if ($dsl) {
	$rrd = 'var/www/html/noc/cacti/bmm_dsl.rrd';
}

# if rrdtool database doesn't exist, create it
if (! -e "$rrd") {

	my $rrd_init = ""
		." DS:dfr:GAUGE:600:-1:U"
		." DS:ufr:GAUGE:600:-1:U"
		."";
	if ($dsl) {
		$rrd_init = ""
			." DS:dla:GAUGE:600:-1:U"
			." DS:ula:GAUGE:600:-1:U"
			." DS:dsp:GAUGE:600:-1:U"
			." DS:usp:GAUGE:600:-1:U"
			."";
	}

	print "creating rrd database for signal data...\n";
	system("$rrdtool create $rrd -s 300"
		." DS:dsn:GAUGE:600:-1:100"
		." DS:usn:GAUGE:600:-1:100"
		." DS:dpl:GAUGE:600:-100:100"
		." DS:upl:GAUGE:600:-1:200"
		.$rrd_init
		." RRA:AVERAGE:0.5:1:576"
		." RRA:AVERAGE:0.5:6:672"
		." RRA:AVERAGE:0.5:24:732"
		." RRA:AVERAGE:0.5:144:1460");
}

# insert values into rrd
printDebug(1, "Inserting values into rrd");

my $rrd_t = "dsn:usn:dpl:upl";
my $rrd_n = "N:$data{'dsn'}:$data{'usn'}:$data{'dpl'}:$data{'upl'}";
if ($cable) {
	$rrd_t = $rrd_t.":dfr:ufr";
	$rrd_n = $rrd_n.":$data{'dfr'}:$data{'ufr'}";
}
if ($dsl) {
	$rrd_t = $rrd_t.":dla:ula:dsp:usp";
	$rrd_n = $rrd_n.":$data{'dla'}:$data{'ula'}:$data{'dsp'}:$data{'usp'}";
}
`$rrdtool update $rrd -t $rrd_t $rrd_n`;

# this creates a 'good' range display at the end of each line
my ($dsn_good, $usn_good, $dpl_good, $upl_good) = ("", "", "", "");
my ($dla_good, $ula_good, $dsp_good, $usp_good) = ("", "", "", "");
my ($dsn_graph, $usn_graph, $dpl_graph, $upl_graph) = ("", "", "", "");
my ($dla_graph, $ula_graph, $dsp_graph, $usp_graph) = ("", "", "", "");
my ($max_text, $min_text, $cur_text) = ("", "", "");
my $gen_graph = "";

# create graphs
printDebug(1, "Generating graphs");
createGraphs("day");
createGraphs("week");
createGraphs("month"); 
createGraphs("year");

# first check if we are supposed to send email, then test the values
$params{'email_subject'} = "Broadband modem signal out of range on ".`hostname`."";
my @email_body = ("Broadband Modem Monitor generated message(s):\n\n");
if ($params{'email_notify'} && &checkValues) {
	use SRK::SMTP;
	my $smtp = new SRK::SMTP(\%params);
	$smtp->send([@email_body]);
}

my $graph_time = scalar localtime(`rrdtool last $rrd`);

my %status = (
	'cm_url'	=>	"http://$params{'host'}:$params{'port'}/",
	'config_file'	=>	$params{'status_file'},
	'fwv'		=>	$data{'fwv'},
	'modem_name'	=>	$params{'modem_name'},
	'modem_type'	=>	$params{'modem_type'},
	'graph_time'	=>	$graph_time
	);

$bmm->writeConfigFile(\%status);

sub createGraphs {
# creates graphs
# inputs: $_[0]: interval (ie, day, week, month, year)

	if ($cable && $params{'display_good'}) {
		$dsn_good = " COMMENT:\"Good\: \>$params{'dsn_min'}\"";
		$usn_good = " COMMENT:\"Good\: \>$params{'usn_min'}\"";
		$dpl_good = " COMMENT:\"Good\: \>$params{'dpl_min'} / <$params{'dpl_max'}\"";
		$upl_good = " COMMENT:\"Good\: \<$params{'upl_max'}\"";
	}
	elsif ($dsl && $params{'display_good'}) {
		#$dsn_good = " COMMENT:\"Good\: \>$params{'dsn_min'} / <$params{'dsn_max'}\"";
		#$usn_good = " COMMENT:\"Good\: \>$params{'usn_min'} / <$params{'usn_max'}\"";
		#$dpl_good = " COMMENT:\"Good\: \>$params{'dpl_min'} / <$params{'dpl_max'}\"";
		#$upl_good = " COMMENT:\"Good\: \>$params{'upl_min'} / <$params{'upl_max'}\"";
		#$dla_good = " COMMENT:\"Good\: \>$params{'dla_min'} / <$params{'dla_max'}\"";
		#$ula_good = " COMMENT:\"Good\: \>$params{'ula_min'} / <$params{'ula_max'}\"";
		#$dsp_good = " COMMENT:\"Good\: \>$params{'dsp_min'} / <$params{'dsp_max'}\"";
		#$usp_good = " COMMENT:\"Good\: \>$params{'usp_min'} / <$params{'usp_max'}\"";
	}

	# format the max, min and current display text
	$max_text = "MAX:\" Max\\:%3.0lf %s\"";
	$min_text = "MIN:\" Min\\:%3.0lf %S\"";
	$cur_text = "LAST:\"Current\\:%3.0lf %S\"";

	# these are the general parameters for all the graphs
	$gen_graph = " -s \"-1$_[0]\""
		#." --lazy"
		." -h 100 -w 500"
		#." -l 0"
		." -a PNG";

	# set up the curve and text for the downstream power level
	$dpl_graph = " DEF:dpl=$rrd:dpl:AVERAGE"
		." LINE2:dpl#"
		.$params{'dpl_color'}
		.":'Downstream $params{'title_pl'} '"
		." GPRINT:dpl:".$max_text
		." GPRINT:dpl:".$min_text
		." GPRINT:dpl:".$cur_text
		.$dpl_good
		." COMMENT:\"\\n\"";

	# set up the curve and text for the upstream power level
	$upl_graph = " DEF:upl=$rrd:upl:AVERAGE"
		." LINE2:upl#"
		.$params{'upl_color'}
		.":'Upstream $params{'title_pl'}   '"
		." GPRINT:upl:".$max_text
		." GPRINT:upl:".$min_text
		." GPRINT:upl:".$cur_text
		.$upl_good
		." COMMENT:\"\\n\"";

	# set up the curve and text for the downstream signal/noise ratio
	$dsn_graph = " DEF:dsn=$rrd:dsn:AVERAGE"
		." LINE2:dsn#"
		.$params{'dsn_color'}
		.":'Downstream $params{'title_sn'}'"
		." GPRINT:dsn:".$max_text
		." GPRINT:dsn:".$min_text
		." GPRINT:dsn:".$cur_text
		.$dsn_good
		." COMMENT:\"\\n\"";

	# set up the curve and text for the upstream signal/noise ratio
	if ($dsl) {
		$usn_graph = " DEF:usn=$rrd:usn:AVERAGE"
			." LINE2:usn#"
			.$params{'usn_color'}
			.":'Upstream $params{'title_sn'}  '"
			." GPRINT:usn:".$max_text
			." GPRINT:usn:".$min_text
			." GPRINT:usn:".$cur_text
			.$usn_good
			." COMMENT:\"\\n\"";

		# set up the curve and text for the downstream speed
		$dsp_graph = " DEF:dsp=$rrd:dsp:AVERAGE"
			." LINE2:dsp#"
			.$params{'dsp_color'}
			.":'Downstream $params{'title_sp'}'"
			." GPRINT:dsp:".$max_text
			." GPRINT:dsp:".$min_text
			." GPRINT:dsp:".$cur_text
			." COMMENT:\"\\n\"";

		# set up the curve and text for the upstream speed
		$usp_graph = " DEF:usp=$rrd:usp:AVERAGE"
			." LINE2:usp#"
			.$params{'usp_color'}
			.":'Upstream $params{'title_sp'}  '"
			." GPRINT:usp:".$max_text
			." GPRINT:usp:".$min_text
			." GPRINT:usp:".$cur_text
			." COMMENT:\"\\n\"";

		# set up the curve and text for the downstream attenuation
		$dla_graph = " DEF:dla=$rrd:dla:AVERAGE"
			." LINE2:dla#"
			.$params{'dla_color'}
			.":'Downstream $params{'title_la'}'"
			." GPRINT:dla:".$max_text
			." GPRINT:dla:".$min_text
			." GPRINT:dla:".$cur_text
			.$dla_good
			." COMMENT:\"\\n\"";

		# set up the curve and text for the upstream attenuation
		$ula_graph = " DEF:ula=$rrd:ula:AVERAGE"
			." LINE2:ula#"
			.$params{'ula_color'}
			.":'Upstream $params{'title_la'}  '"
			." GPRINT:ula:".$max_text
			." GPRINT:ula:".$min_text
			." GPRINT:ula:".$cur_text
			.$ula_good
			." COMMENT:\"\\n\"";
	}

	my $image_file;

	# create the power level graph
	$image_file = "$img/bmm_pl-$_[0].png";
	printDebug(1, "Generating $image_file");
	system("$rrdtool graph $image_file"
		." -t \"$params{'title_pl'} over the last $_[0]\""
		." -v \"dBmV\""
		.$gen_graph
		.$dpl_graph
		.$upl_graph
		);

	# create the signal/noise ratio graph
	$image_file = "$img/bmm_sn-$_[0].png";
	printDebug(1, "Generating $image_file");
	system("$rrdtool graph $image_file"
		." -t \"$params{'title_sn'} over the last $_[0]\""
		." -v \"dB\""
		.$gen_graph
		.$dsn_graph
		.$usn_graph
		);

	if ($dsl) {
		# create the attenuation graph
		$image_file = "$img/bmm_la-$_[0].png";
		printDebug(1, "Generating $image_file");
		system("$rrdtool graph $image_file"
			." -t \"$params{'title_la'} over the last $_[0]\""
			." -v \"dB\""
			.$gen_graph
			.$dla_graph
			.$ula_graph
			);

		# create the speed graph
		$image_file = "$img/bmm_sp-$_[0].png";
		printDebug(1, "Generating $image_file");
		system("$rrdtool graph $image_file"
			." -t \"$params{'title_sp'} over the last $_[0]\""
			." -v \"kb/s\""
			.$gen_graph
			.$dsp_graph
			.$usp_graph
			);
	}
}

sub checkValues {
	my $range_error = 0;
	if ($data{'dsn'} ne "NaN" && $data{'dsn'} <= $params{'dsn_min'} || $data{'dsn'} >= $params{'dsn_max'}) {
		push(@email_body, "Downstream Signal/Noise Ratio is out of range\n");
		push(@email_body, "     Valid range: $params{'dsn_min'} to $params{'dsn_max'} dB\n");
		push(@email_body, "     Current value: $data{'dsn'} dB\n");
		push(@email_body, "\n");
		$range_error = 1;
	}
	if ($data{'usn'} ne "NaN" && $data{'usn'} <= $params{'usn_min'} || $data{'usn'} >= $params{'usn_max'}) {
		push(@email_body, "Upstream Signal/Noise Ratio is out of range\n");
		push(@email_body, "     Valid range: $params{'usn_min'} to $params{'usn_max'} dB\n");
		push(@email_body, "     Current value: $data{'usn'} dB\n");
		push(@email_body, "\n");
		$range_error = 1;
	}
	if ($data{'dpl'} ne "NaN" && $data{'dpl'} <= $params{'dpl_min'} || $data{'dpl'} >= $params{'dpl_max'}) {
		push(@email_body, "Downstream Power Level is out of range\n");
		push(@email_body, "     Valid range: $params{'dpl_min'} to $params{'dpl_max'} dB\n");
		push(@email_body, "     Current value: $data{'dpl'} dBmV\n");
		push(@email_body, "\n");
		$range_error = 1;
	}
	if ($data{'upl'} ne "NaN" && $data{'upl'} <= $params{'upl_min'} || $data{'upl'} >= $params{'upl_max'}) {
		push(@email_body, "Upstream Power Level is out of range\n");
		push(@email_body, "     Valid range: $params{'upl_min'} to $params{'upl_max'} dB\n");
		push(@email_body, "     Current value: $data{'upl'} dBmV\n");
		push(@email_body, "\n");
		$range_error = 1;
	}
	if ($data{'dla'} ne "NaN" && $data{'dla'} <= $params{'dla_min'} || $data{'dla'} >= $params{'dla_max'}) {
		push(@email_body, "Downstream Line Attenuation is out of range\n");
		push(@email_body, "     Valid range: $params{'dla_min'} to $params{'dla_max'} dB\n");
		push(@email_body, "     Current value: $data{'dla'} dB\n");
		push(@email_body, "\n");
		$range_error = 1;
	}
	if ($data{'ula'} ne "NaN" && $data{'ula'} <= $params{'ula_min'} || $data{'ula'} >= $params{'ula_max'}) {
		push(@email_body, "Upstream Line Attenuation is out of range\n");
		push(@email_body, "     Valid range: $params{'ula_min'} to $params{'ula_max'} dB\n");
		push(@email_body, "     Current value: $data{'ula'} dB\n");
		push(@email_body, "\n");
		$range_error = 1;
	}
	if ($data{'dsp'} ne "NaN" && $data{'dsp'} <= $params{'dsp_min'} || $data{'dsp'} >= $params{'dsp_max'}) {
		push(@email_body, "Downstream Speed is out of range\n");
		push(@email_body, "     Valid range: $params{'dsp_min'} to $params{'dsp_max'} dB\n");
		push(@email_body, "     Current value: $data{'dsp'} kb/s");
		push(@email_body, "\n");
		$range_error = 1;
	}
	if ($data{'usp'} ne "NaN" && $data{'usp'} <= $params{'usp_min'} || $data{'usp'} >= $params{'usp_max'}) {
		push(@email_body, "Upstream Speed is out of range\n");
		push(@email_body, "     Valid range: $params{'usp_min'} to $params{'usp_max'} dB\n");
		push(@email_body, "     Current value: $data{'usp'} kb/s");
		push(@email_body, "\n");
		$range_error = 1;
	}
	return $range_error;
}

sub printDebug {
	if ($debug >= $_[0]) {
		printf "***bmm.pl*** $_[1]\n";
	}
}
